# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.24.0~6f08ce1',
    built_at='2025-11-04 08:26:32Z',
    sha='6f08ce19d7480a17290d9ff53a9ceac15af93ce8',
    branch='HEAD',
    tag='v4.24.0',
)
